@@ -554,7 +554,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                 if block:
                     return ___keep_circulating()
                 else:
-                    threading.Thread(target=___keep_circulating, ).start()
+                    threading.Thread(target=___keep_circulating, daemon=True).start()
 
             return __keep_circulating
 
@@ -1052,15 +1052,14 @@ class ConcurrentModeDispatcher(LoggerMixin):
 
     def schedulal_task_with_no_block(self):
         if ConsumersManager.schedual_task_always_use_thread:
-            t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
+            t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task), daemon=True)
             ConsumersManager.schedulal_thread_to_be_join.append(t)
             t.start()
-        else:
-            if self._concurrent_mode in [ConcurrentModeEnum.THREADING, ConcurrentModeEnum.ASYNC,
+        elif self._concurrent_mode in [ConcurrentModeEnum.THREADING, ConcurrentModeEnum.ASYNC,
                                          ConcurrentModeEnum.SINGLE_THREAD, ]:
-                t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task), daemon=True)
-                ConsumersManager.schedulal_thread_to_be_join.append(t)
-                t.start()
+            t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task), daemon=True)
+            ConsumersManager.schedulal_thread_to_be_join.append(t)
+            t.start()
 
 
 def wait_for_possible_has_finish_all_tasks_by_conusmer_list(consumer_list: typing.List[AbstractConsumer], minutes: int = 3):
