@@ -27,6 +27,8 @@ class LocalPythonQueueConsumer(AbstractConsumer):
             # self.logger.debug(f'从当前python解释器内部的 [{self._queue_name}] 队列中 取出的消息是：  {json.dumps(task)}  ')
             kw = {'body': task}
             self._submit_task(kw)
+            if self._stop_flag:
+                break
 
     def _confirm_consume(self, kw):
         pass
